@@ -11,7 +11,7 @@ import vapoursynth as vs
 from PyQt6 import sip
 from PyQt6.QtCore import Qt
 from PyQt6.QtGui import QColorSpace, QImage, QPainter, QPixmap
-from jetpytools import cachedproperty, classproperty, fallback
+from jetpytools import classproperty, fallback
 
 from ..abstracts import AbstractYAMLObject, main_window, try_load
 from ..bases import yaml_Loader
@@ -72,13 +72,12 @@ class PackingType():
     vszip_8bit = PackingTypeInfo('vszip_8bit', vs.RGB24, QImage.Format.Format_RGB32, False)
     vszip_10bit = PackingTypeInfo('vszip_10bit', vs.RGB30, QImage.Format.Format_BGR30, True)
 
-    @cachedproperty
-    @classproperty
+    @classproperty.cached
     @classmethod
     def CURRENT(cls) -> PackingTypeInfo:
         _default_10bits = os.name != 'nt' and QPixmap.defaultDepth() == 30
 
-        if hasattr(vs.core, 'vszip'):
+        if hasattr(vs.core, 'vszip') and hasattr(vs.core.vszip, "PackRGB"):
             return PackingType.vszip_10bit if _default_10bits else PackingType.vszip_8bit
         else:
             try:
